@@ -203,11 +203,4 @@ function toSVG(descriptor) {
   return node;
 }
 
-/**
- * Copyright IBM Corp. 2018, 2018
- *
- * This source code is licensed under the Apache-2.0 license found in the
- * LICENSE file in the root directory of this source tree.
- */
-
-export { defaultAttributes, getAttributes, formatAttributes, toString, toSVG };
+export { defaultAttributes, formatAttributes, getAttributes, toSVG, toString };
